@@ -27,8 +27,8 @@ from peek_platform.file_config.PeekFileConfigHttpServerMixin import (
 from peek_platform.file_config.PeekFileConfigOsMixin import (
     PeekFileConfigOsMixin,
 )
-from peek_platform.file_config.PeekFileConfigPeekServerClientMixin import (
-    PeekFileConfigPeekServerClientMixin,
+from peek_platform.file_config.PeekFileConfigDataExchangeClientMixin import (
+    PeekFileConfigDataExchangeClientMixin,
 )
 from peek_platform.file_config.PeekFileConfigPlatformMixin import (
     PeekFileConfigPlatformMixin,
@@ -39,7 +39,6 @@ logger = logging.getLogger(__name__)
 
 class PeekClientConfig(
     PeekFileConfigABC,
-    PeekFileConfigPeekServerClientMixin,
     PeekFileConfigPlatformMixin,
     PeekFileConfigOsMixin,
     PeekFileConfigFrontendDirMixin,
@@ -52,3 +51,4 @@ class PeekClientConfig(
     def __init__(self):
         super().__init__()
         self.fieldHttpServer = PeekFileConfigHttpMixin(self, "field", 8000)
+        self.dataExchange = PeekFileConfigDataExchangeClientMixin(self)
